API Reference
=============

.. currentmodule:: qualpipe

.. autosummary::
   :toctree: _autosummary
   :recursive:

   core
   tools

.. automodule:: qualpipe
   :members:
   :undoc-members:
   :show-inheritance:
